function [obj,cpu_time,gap,node]=RefCplex(Q,u,xi,R,alpha,beta,K,T,n,seta)
% solve the reformulated problem with cplex
%(MIQP_\theta)  minimize  x'(Q-B' \xi diag(\theta) \xi' B)x+c'x+sum( \theta_i*(w_i^2+phi_i-R^2y_i) )
%                          subject to (\xi^i)'Bx=w_i+z_i-y_iR,  i=1,...,N,
%                                            e'y<=K, y=0 or 1,
%                                            \alpha_i y_i <= z_i<= Ry_i,  phi_i y_i >= z_i^2, phi_i >=  0,  R<=w_i<=\beta_i,  i=1,..., N,
%                                            x\in X={x\in R | 0<=x<=u,
%                                            Ex<=f, E is m*n matrix

reform=Cplex();
reform.Param.simplex.limits.iterations.Cur = 1000000000;
reform.Param.timelimit.Cur=2*3600;
reform.Param.mip.strategy.miqcpstrat.Cur=1; % use QCP relaxation at each node
reform.Param.emphasis.memory.Cur=0; % reduce use of memory;
reform.Param.mip.strategy.file.Cur=0;% node storage file switch;
reform.Param.output.clonelog.Cur = 0; % Turn off clone log
reform.Param.threads.Cur = 1; % Disable parallel mode

reform.Model.sense='minimize';

% Fill in the data
dim=n+4*T; % decision variable (x,y,phi,z), x: 1:n, y:n+1:n+T; phi:n+T+1:n+2T;
%  z:n+2T+1:n+3T, w: n+3T+1:n+4T
cstar=zeros(dim,1);
cstar(n+1:n+T,1)=-R^2*seta; %y
cstar(n+T+1:n+2*T,1)=seta ;%phi
lb=-inf*ones(dim,1); lb(1:n+2*T,1)=0;% x,y,phi
ub=inf*ones(dim,1);ub(1:n,1)=u; % x
ub(n+1:n+T,1)=1;%y
lb(n+3*T+1:n+4*T,1)=R; ub(n+3*T+1:n+4*T,1)=beta;
mytype(1:dim)='C'; mytype(n+1:n+T)='B';
reform.addCols(cstar,[],lb,ub,mytype);% linear term and bound of variable

Qstar=zeros(dim,dim);
Qstar(1:n,1:n)=Q-xi*diag(seta)*xi';%x
Qstar(n+3*T+1:n+4*T,n+3*T+1:n+4*T)=diag(seta); % w
Qstar=Qstar+1.e-4*eye(dim); Qstar=2*Qstar;
for i=1:dim
    for j=1:dim
        Qstar(i,j)=Qstar(j,i);
    end
end
reform.Model.Q=Qstar;% quadratic objective matrix


Ain=zeros(2*T+1,dim);
Ain(1:2*T,n+1:n+T)=[-R*eye(T);diag(alpha)]; Ain(1:2*T,n+2*T+1:n+3*T)=[eye(T);-eye(T)]; % -Ry_i+z_i<=0; alpha_iy_i-z_i<=0
Ain(2*T+1,n+1:n+T)=1; % e^T y <= K
bin=[zeros(2*T,1);K];
reform.addRows(-inf*ones(2*T+1,1), Ain, bin); % linear inequality constraint

reform.addRows(1,[ones(1,n),zeros(1,4*T)],1); % sum(x)=1;

Aeq=zeros(T,dim); % xi' x+R*y-z-w=0.
Aeq(:,1:n)=xi'; Aeq(:,n+1:n+T)=R*eye(T); Aeq(:,n+2*T+1:n+4*T)=[-eye(T),-eye(T)];
reform.addRows(zeros(T,1), Aeq, zeros(T,1)); % linear equality constraint

for i=1:T
    aa=zeros(dim,1);Qi=zeros(dim,dim);Qi(2*T+n+i,2*T+n+i)=1;Qi(n+i,n+T+i)=-0.5;Qi(n+T+i,n+i)=-0.5;
    reform.addQCs(aa, Qi, 'L', 0.0);% quadratic constraint: z_i^2-phi_i y_i <= 0;
end


reform.solve();

%*******************************************
% Ouput the results




if  isfield( reform.Solution, 'objval' )
    obj = reform.Solution.objval;
    cpu_time = reform.Solution.time;
    gap = reform.Solution.miprelgap ;
    if  isfield( reform.Solution, 'nodecnt' )
        node = reform.Solution.nodecnt;
    else
        node = 1;
    end % End if
else % "else" means the problem is infeasible
    obj = NaN;
    cpu_time = NaN;
    gap = NaN;
    node = NaN;
end

end % End RefCplex
