function [ obj, cpu_time, gap, node ] = standardFormulationWithEquality(  Q, u, xi, R, alpha, K, T, n )

qcp1 = Cplex();
qcp1.Param.simplex.limits.iterations.Cur = 1000000000;
qcp1.Param.timelimit.Cur = 2 * 3600; % set timelimit=3600 s
qcp1.Param.mip.strategy.miqcpstrat.Cur = 1; % qcp relaxation
qcp1.Param.emphasis.memory.Cur = 0; % reduce use of memory;
qcp1.Param.mip.strategy.file.Cur = 0; % node storage file switch;
qcp1.Param.threads.Cur = 1; % Disable parallel mode
qcp1.Model.sense = 'minimize';

dim = n + T; % number of decision variables (x,y);
cstar = zeros( dim, 1 );
lb = zeros( dim, 1 );
ub = ones( dim, 1 );
ub( 1 : n, 1 ) = u;
ctype( 1 : n ) = 'C'; 
ctype( n + 1 : dim ) = 'B';
qcp1.addCols( cstar, [], lb, ub, ctype ); % linear term of objective; bound of variables

Ain = zeros( T + 1, dim );
Ain( 1 : T, : ) = [ - xi', diag( alpha - R * ones( T, 1 ) ) ];
Ain( T + 1, n + 1 : dim ) = 1;
bin = [ - R * ones( T, 1 ); K ];
binLeft = [ - inf * ones( T, 1 ); K ]; % to get equality constraint
qcp1.addRows( binLeft, Ain, bin ); % linear constraints

qcp1.addRows( 1, [ ones( 1, n ), zeros( 1, T ) ], 1 ); % liner equality : sum(x)=1

for i = 1 : n
    aa = zeros( dim, 1 );
    aa( i, 1 ) = - u( i, 1 );
    Qi = zeros( dim, dim );
    Qi( i, i ) = 1;
    qcp1.addQCs( aa, Qi, 'L', 0 );% quadratic constraint: x_i^2-u_ix_i<=0
end

Qstar = zeros( dim, dim );
Qstar( 1 : n, 1 : n ) = 2 * Q;
qcp1.Model.Q = Qstar; % quadratic objective
qcp1.solve();

% results of cplex

if  isfield( qcp1.Solution, 'objval' )
    obj = qcp1.Solution.objval;
    cpu_time = qcp1.Solution.time;
    gap = qcp1.Solution.miprelgap ;
    if  isfield( qcp1.Solution, 'nodecnt' )
        node = qcp1.Solution.nodecnt;
    else
        node = 1;
    end % End if
else % "else" means the problem is infeasible
    obj = NaN;
    cpu_time = NaN;
    gap = NaN;
    node = NaN;
end

end % End standardFormulationWithEquality

